############################################
#### Andrew Osborne May 2023 ####
#### Chat Moss Hectares ####
############################################

setwd("~/Desktop/PC_Folders/LHB/Manuscripts/ChatMoss_Ecosystem/Supplemental_data")
list.files(pattern=".csv")
#Load data
Ha <-read.csv("Areas.csv")
names(Ha)
#Aggregate areas of primary and secondary mossland from each map 
H_Y <-aggregate(Ha$Hectares, list(Ha$Year), sum)
colnames(H_Y)[colnames(H_Y)=="x"] <-"Hectares"
colnames(H_Y)[colnames(H_Y)=="Group.1"] <-"Year"
H_Y
#Linear regression
H_Y.lm <-lm(Hectares~Year,data=H_Y)
summary(H_Y.lm)
#Localised regression
H_Y.ls <-loess(Hectares~Year,data=H_Y)
summary(H_Y.ls)
#Predict values from Loess
range(H_Y$Year)
xYears<-seq(1577,2023,1)
yHectares <- predict(H_Y.ls, newdata=xYears)
#Make new data frame
HY.pred.df <-data.frame(xYears,yHectares)
HY.pred.df
#Locate the year when the half of the 1577 area has been lost
HY.pred.df[which.min(abs(2949/2-HY.pred.df$yH_Y)),]
HY.pred.df[which.min(abs(2949/2-HY.pred.df$yHectares)),]

##Segmented regression to isolate inflection points
#Generate a model of the logistic curve for 'segmented' to work from
#(Here we are analyzing the shape of the curve, not the raw data)
HY.pred.mod <-lm(yHectares~xYears,data=HY.pred.df)#Run the segmented regression
library(segmented)
HY.pred.segmented <- segmented(HY.pred.mod, seg.Z = ~xYears, psi=c(1700,1850)) 
summary(HY.pred.segmented)#inflection points at 1779 and 1898

####Plot area of mossland####
library(ggplot2)
library(ggrepel)
H_Y
H_Y$Hectares <-signif(H_Y$Hectares, digits = 4)

#Print width 27.3cm
 HY.gg <-ggplot(data = H_Y, aes(x = Year , y = Hectares)) +
   geom_point()+
   scale_y_continuous(limits = c(-900,3000))+
   scale_x_continuous(limits = c(1450,2190))+
   coord_fixed(ratio=0.15)+
 
   ##Species Timeline
   annotate(geom="text", x=1960,y=3000,label = "LAST_INDUSTRIAL-ERA_BIOLOGICAL_RECORDING", angle = 0,parse = TRUE,size=5)+ 
   geom_segment(aes(x=1748,y=2955,xend=2172,yend=2955), color="black",size=0.55, linetype=1)+
   
   annotate(geom="text", x=2095,y=400,label = "purple-bordered_gold_moth: 1964", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=2107,y=360,xend=2140,yend=360), color="white",size=1, linetype=1)+
   geom_segment(aes(x=2090,y=360,xend=2100,yend=360), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1974,y=20,xend=1984,yend=400), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=2032,y=600,label = "fen_wainscot: 1940", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1980,y=560,xend=2010,yend=560), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1940,y=60,xend=1970,yend=600), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=2051,y=800,label = "large_heath_butterfly: 1926", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1990,y=760,xend=2050,yend=760), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1926,y=80,xend=1964,yend=800), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=2066,y=1000,label = "Manchester_treble-bar_moth: 1912", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=2000,y=960,xend=2140,yend=960), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1912,y=120,xend=1952,yend=1010), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=2023,y=1200,label = "white_beak-sedge: 1900", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1950,y=1150,xend=2000,yend=1160), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1900,y=190,xend=1940,yend=1200), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1990,y=1400,label = "italic(Sphagnum): 1871", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1871,y=745,xend=1928,yend=1400), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1990,y=1600,label = "greater_sundew: 1868", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1960,y=1560,xend=1990,yend=1560), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1868,y=770,xend=1919,yend=1600), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1970,y=1800,label = "bilberry_pug: 1862", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1956,y=1760,xend=1965,yend=1760), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1862,y=820,xend=1910,yend=1800), color="darkgrey",size=0.5, linetype=2)+
   
   ##Historical Timeline
   annotate(geom="text", x=1590,y=-420,label = "HISTORICAL_EVENTS", angle = 0,parse = TRUE,size=5)+ 
   geom_segment(aes(x=1498,y=-465,xend=1681,yend=-465), color="black",size=0.5, linetype=1)+
   
   annotate(geom="text", x=1547,y=2595,label = "1724-27: Daniel_Defoe_visit", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1700,y=2550,xend=1550,yend=2550), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1720,y=2675,xend=1450,yend=2675), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1575,y=2140,label = "1780: Bridgewater_canal_construction", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1700,y=2095,xend=1550,yend=2095), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1730,y=2060,xend=1450,yend=2060), color="darkgrey",size=0.5, linetype=2)+
   geom_segment(aes(x=1733,y=2080,xend=1780,yend=2400), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1576,y=1820,label = "1828: Newton_chemical_works_opens", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1664,y=1780,xend=1450,yend=1780), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1775,y=1760,xend=1827,yend=1584), color="darkgrey",size=0.5, linetype=2)+
   geom_segment(aes(x=1450,y=1760,xend=1774,yend=1760), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1610,y=1630,label = "1829: George_Stephenson_railway_construction", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1672,y=1590,xend=1750,yend=1590), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1620,y=1590,xend=1650,yend=1590), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1540,y=1590,xend=1560,yend=1590), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1450,y=1570,xend=1829,yend=1570), color="darkgrey",size=0.4, linetype=2)+
   
   annotate(geom="text", x=1549,y=1390,label = "1832: Half_of_1577_area_lost", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1450,y=1350,xend=1700,yend=1350), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1450,y=1465,xend=1832,yend=1465), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1590,y=350,label = "1897: Manchester_ship_canal_construction", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1500,y=310,xend=1590,yend=310), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1598,y=310,xend=1700,yend=310), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1450,y=280,xend=1890,yend=280), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1561,y=172,label = "1900: Peak_of_Industial_Pollution", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1500,y=127,xend=1620,yend=127), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1450,y=250,xend=1890,yend=250), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1605,y=-70,label = "2020: Fiddlers_Ferry_coal_power_station_closes", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1500,y=-115,xend=1570,yend=-115), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1583,y=-115,xend=1632,yend=-115), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1640,y=-115,xend=1800,yend=-115), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1450,y=0,xend=2020,yend=0), color="darkgrey",size=0.5, linetype=2)+
   
   
   ##Species Reappearance
   annotate(geom="text", x=2060,y=-800,label = "POST-INDUSTRIAL_RECOVERY", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1938,y=-845,xend=2178,yend=-845), color="black",size=0.55, linetype=1)+
   
   annotate(geom="text", x=2060,y=-400,label = "species_reintroductions_from_2012_onwards", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1950,y=-440,xend=2160,yend=-440), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1955,y=-350,xend=2012,yend=0), color="darkgrey",size=0.5, linetype=2)+
   
   annotate(geom="text", x=1920,y=-600,label = "italic(Sphagnum):  Recorded_1989", angle = 0,parse = TRUE,size=4.5)+ 
   geom_segment(aes(x=1850,y=-640,xend=2000,yend=-640), color="white",size=1, linetype=1)+
   geom_segment(aes(x=1870,y=-550,xend=1989,yend=10), color="darkgrey",size=0.5, linetype=2)+
   
   
   #Grid lines
   #geom_segment(aes(x=1450,y=-200,xend=1450,yend=3000), color="darkgrey",size=0.5, linetype=3)+
   #geom_segment(aes(x=2000,y=-50,xend=1850,yend=3000), color="darkgrey",size=0.5, linetype=3)+
   #Plot loess
   
   stat_smooth(method = "loess", fullrange=TRUE, se=FALSE)+theme_bw()+
   geom_label_repel(aes(label=paste(Hectares, "Ha")),cex=4.5,box.padding=0.316,col="blue")+
   ylab("Hectares of Primary and Secondary Mossland Habitat")+
   xlab("Year")
 
                  print(HY.gg, width=unit(27.5,"cm"), height=unit(19.5,"cm"))
 
              
